package sun.security.pkcs12;

import sun.security.util.DerOutputStream;
import java.security.NoSuchAlgorithmException;
import java.io.IOException;
import sun.security.util.DerValue;
import sun.security.pkcs.ParsingException;
import sun.security.x509.AlgorithmId;
import sun.security.util.DerInputStream;
import java.security.AlgorithmParameters;

class MacData
{
    private String digestAlgorithmName;
    private AlgorithmParameters digestAlgorithmParams;
    private byte[] digest;
    private byte[] macSalt;
    private int iterations;
    private byte[] encoded;
    
    MacData(DerInputStream derInputStream) throws IOException, ParsingException {
        this.encoded = null;
        DerValue[] sequence = derInputStream.getSequence(2);
        if (sequence.length < 2 || sequence.length > 3) {
            throw new ParsingException("Invalid length for MacData");
        }
        DerValue[] sequence2 = new DerInputStream(sequence[0].toByteArray()).getSequence(2);
        if (sequence2.length != 2) {
            throw new ParsingException("Invalid length for DigestInfo");
        }
        AlgorithmId parse = AlgorithmId.parse(sequence2[0]);
        this.digestAlgorithmName = parse.getName();
        this.digestAlgorithmParams = parse.getParameters();
        this.digest = sequence2[1].getOctetString();
        this.macSalt = sequence[1].getOctetString();
        if (sequence.length > 2) {
            this.iterations = sequence[2].getInteger();
        }
        else {
            this.iterations = 1;
        }
        return;
    }
    
    MacData(String algname, byte[] array, byte[] macSalt, int iterations) throws NoSuchAlgorithmException {
        this.encoded = null;
        if (algname == null) {
            throw new NullPointerException("the algName parameter must be non-null");
        }
        AlgorithmId value = AlgorithmId.get(algname);
        this.digestAlgorithmName = value.getName();
        this.digestAlgorithmParams = value.getParameters();
        if (array == null) {
            throw new NullPointerException("the digest parameter must be non-null");
        }
        if (array.length == 0) {
            throw new IllegalArgumentException("the digest parameter must not be empty");
        }
        this.digest = (byte[])array.clone();
        this.macSalt = macSalt;
        this.iterations = iterations;
        this.encoded = null;
        return;
    }
    
    MacData(AlgorithmParameters algparams, byte[] array, byte[] macSalt, int iterations) throws NoSuchAlgorithmException {
        this.encoded = null;
        if (algparams == null) {
            throw new NullPointerException("the algParams parameter must be non-null");
        }
        AlgorithmId value = AlgorithmId.get(algparams);
        this.digestAlgorithmName = value.getName();
        this.digestAlgorithmParams = value.getParameters();
        if (array == null) {
            throw new NullPointerException("the digest parameter must be non-null");
        }
        if (array.length == 0) {
            throw new IllegalArgumentException("the digest parameter must not be empty");
        }
        this.digest = (byte[])array.clone();
        this.macSalt = macSalt;
        this.iterations = iterations;
        this.encoded = null;
        return;
    }
    
    String getDigestAlgName() {
        return this.digestAlgorithmName;
    }
    
    byte[] getSalt() {
        return this.macSalt;
    }
    
    int getIterations() {
        return this.iterations;
    }
    
    byte[] getDigest() {
        return this.digest;
    }
    
    public byte[] getEncoded() throws NoSuchAlgorithmException, IOException {
        if (this.encoded != null) {
            return (byte[])this.encoded.clone();
        }
        DerOutputStream derOutputStream = new DerOutputStream();
        DerOutputStream derOutputStream2 = new DerOutputStream();
        DerOutputStream out = new DerOutputStream();
        AlgorithmId.get(this.digestAlgorithmName).encode(out);
        out.putOctetString(this.digest);
        derOutputStream2.write((byte)48, out);
        derOutputStream2.putOctetString(this.macSalt);
        derOutputStream2.putInteger(this.iterations);
        derOutputStream.write((byte)48, derOutputStream2);
        this.encoded = derOutputStream.toByteArray();
        return (byte[])this.encoded.clone();
    }
}
